<?php

/**
 * Class VitagateTeaserAdmin.
 */
class VitagateTeaserAdmin
{

    /**
     * @var VitagateTeaserPlugin
     */
    protected $_plugin;


    /**
     * VitagateTeaserAdmin constructor.
     *
     * @param VitagateTeaserPlugin $plugin
     */
    public function __construct(VitagateTeaserPlugin $plugin)
    {
        $this->_plugin = $plugin;

        add_action('plugins_loaded', array($this, 'load_textdomain'));

        add_action('admin_init', array($this, 'admin_init'));

        add_action('admin_menu', array($this, 'admin_menu'));

        add_action('admin_footer', array($this, 'admin_footer'));

        add_action('wp_ajax_vitagateteaser', array($this, 'ajax_vitagateteaser'));
    }


    /**
     * Load the text domain.
     */
    public function load_textdomain()
    {
        load_plugin_textdomain(
            'vitagateteaser',
            false,
            plugin_basename(ABS_VITAGATETEASER_PATH) . DIRECTORY_SEPARATOR . 'translations' . DIRECTORY_SEPARATOR
        );
    }


    /**
     * Action handler for 'admin_init' action.
     */
    public function admin_init()
    {
        register_setting(
            'vitagateteaser_plugin_options',
            'vitagateteaser_options',
            array($this, 'options_sanitize')
        );
    }


    /**
     * Action handler for 'admin_menu' action.
     */
    public function admin_menu()
    {
        add_options_page(
            __('Vitagate Teaser', 'vitagateteaser'),
            __('Vitagate Teaser', 'vitagateteaser'),
            'manage_options',
            'vitagateteaser',
            array($this, 'options')
        );
    }


    /**
     * Action handler for 'admin_footer' action.
     */
    public function admin_footer()
    { ?>
        <script type="text/javascript">
            jQuery(document).ready(function ($) {
                $('#clearCache').on('click', function () {
                    var data = {
                        'action': 'vitagateteaser',
                        'todo': 'clearCache'
                    };

                    jQuery.post(ajaxurl, data, function (response) {
                        if (response['status'] == 'OK') {
                            for (var property in response['cacheInfo']) {
                                if (response['cacheInfo'].hasOwnProperty(property)) {
                                    $('[data-cache-info="' + property + '"]').html(response['cacheInfo'][property]);
                                }
                            }
                        } else {
                            alert("Da lief etwas schief :/");
                        }
                    });
                });
            });
        </script>
        <?php
    }


    /**
     * Callback for ajax requests.
     */
    public function ajax_vitagateteaser()
    {
        $todo = filter_input(INPUT_POST, 'todo');
        switch ($todo) {
            case 'clearCache':
                $result = array(
                    'status'    => 'OK',
                    'cacheInfo' => array(),
                );

                foreach (array('de', 'fr') as $langCode) {
                    delete_option('vitagateteaser_' . $langCode);
                    $result['cacheInfo'][$langCode] = '<p>' . esc_html(__('No teaser data fetched so far.',
                            'vitagateteaser')) . '</p>';
                }
                break;

            default:
                $result = array('status' => 'ERROR');
        }
        
        wp_send_json($result);
        wp_die();
    }


    /**
     * Handle the options page.
     */
    public function options()
    {
        if ( ! isset($_REQUEST['updated'])) {
            $_REQUEST['updated'] = false;
        }

        $title = __('Vitagate Teaser Settings', 'vitagateteaser');
        ?>
        <div class="wrap">
            <h1><?php echo esc_html($title); ?></h1>

            <?php if (false !== $_REQUEST['updated']) : ?>
                <div id="message" class="updated notice is-dismissible"><p><?php _e('Options saved'); ?></p></div>
            <?php endif; ?>

            <form method="post" action="options.php" novalidate="novalidate">
                <fieldset>
                    <?php
                    settings_fields('vitagateteaser_plugin_options');
                    $settings = $this->_plugin->options;
                    ?>

                    <table class="form-table">
                        <tr>
                            <th scope="row">
                                <label for="vak">
                                    <?php esc_html_e('Vitagate Access Key (VAK)', 'vitagateteaser'); ?>
                                </label>
                            </th>
                            <td>
                                <input name="vitagateteaser_options[vak]" type="text" id="vak"
                                       value="<?php esc_attr_e($settings['vak']); ?>" class="regular-text"/>
                            </td>
                        </tr>
                        <tr>
                            <th scope="row">
                                <label for="template">
                                    <?php esc_html_e('HTML Template', 'vitagateteaser'); ?>
                                </label>
                            </th>
                            <td>
								<textarea id="template" name="vitagateteaser_options[template]" class="large-text code"
                                          rows="15"><?php esc_html_e($settings['template']); ?></textarea>
                                <p class="description">
                                    <?php esc_html_e('The template that would be used for the display of one vitagate teaser item.',
                                        'vitagateteaser'); ?>
                                </p>
                            </td>
                        </tr>
                    </table>

                    <?php submit_button(); ?>

                </fieldset>
            </form>

            <hr/>

            <?php foreach (array('de' => 'Deutsch', 'fr' => 'Français') as $langCode => $langLabel) : ?>
                <div>
                    <h2><?php echo $langLabel; ?></h2>

                    <?php $shortcode_data = get_option('vitagateteaser_' . $langCode, false); ?>

                    <div data-cache-info="<?php echo $langCode; ?>">
                        <?php if (false == $shortcode_data) : ?>
                            <p><?php esc_html_e('No teaser data fetched so far.', 'vitagateteaser'); ?></p>
                        <?php else: ?>
                            <?php
                            $json = $shortcode_data['json'];
                            if ('OK' === $json->status) : ?>
                                <p><?php printf(__('Number of teasers: %d', 'vitagateteaser'),
                                        count($json->items)); ?></p>
                                <ul style="margin-left: 30px;">
                                    <?php foreach ($json->items as $item): ?>
                                        <li><?php echo $item->title; ?></li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php else: ?>
                                <div class="error-div error"><strong><?php printf(__('Error %d', 'vitagateteaser'),
                                            $json->error_code); ?></strong></div>
                            <?php endif; ?>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endforeach; ?>

            <p class="submit">
                <input id="clearCache" class="button button-primary" value="Cache leeren" type="button">
            </p>
        </div>
        <?php
    }


    /**
     * @param $options
     *
     * @return array
     */
    public function options_sanitize($options)
    {
        if ( ! is_array($options) || empty($options) || (false === $options)) {
            return array();
        }

        return $options;
    }


}