<?php

/**
 * Class VitagateTeaserPlugin.
 */
class VitagateTeaserPlugin
{

    /**
     * @var array
     */
    public $options;


    /**
     * @var VitagateTeaserPluginFactory
     */
    protected $_pluginFactory;

    /**
     * @var VitagateTeaserAdmin
     */
    protected $_admin;

    /**
     * @var int
     */
    private $_teaserIndex = 0;

    /**
     * @var array|false
     */
    private $_shortcode_data = null;


    /**
     * VitagateTeaserPlugin constructor.
     *
     * @param VitagateTeaserPluginFactory $factory
     */
    public function __construct(VitagateTeaserPluginFactory $factory)
    {
        $this->_pluginFactory = $factory;
    }


    /**
     * Setup.
     */
    public function setup()
    {
        // Load the options.
        $this->options = array_merge(array(
            'vak'      => '',
            'template' => '',
        ), get_option('vitagateteaser_options', array()));

        // Add the shortcode
        add_shortcode('vitagate_teaser', array($this, 'vitagate_teaser_shortcode'));

        // Handlers for the Backend only.
        if (is_admin()) {
            $this->_admin = $this->_pluginFactory->buildAdmin($this);
        }
    }


    /**
     * @param $atts
     *
     * @return string
     */
    public function vitagate_teaser_shortcode($atts)
    {
        if (is_null($this->_shortcode_data)) {
            $locale = get_locale();
            if ('fr' === substr($locale, 0, 2)) {
                $lang = 'fr';
            } else {
                $lang = 'de';
            }

            $ymd                   = date('Ymd');
            $optionKey             = 'vitagateteaser_' . $lang;
            $this->_shortcode_data = get_option($optionKey, false);
            if (false === $this->_shortcode_data || $ymd !== $this->_shortcode_data['ymd']) {
                $response = wp_remote_get('http://vitagate.ch/' . $lang . '/rss/front.json?build=' . VITAGATETEASER_BUILD . '&vak=' . urlencode($this->options['vak']));

                if (is_array($response)) {
                    $json = json_decode($response['body']);
                    if (json_last_error() === JSON_ERROR_NONE && 'OK' === $json->status) {
                        $this->_shortcode_data = array(
                            'ymd'  => $ymd,
                            'json' => $json,
                        );
                        update_option($optionKey, $this->_shortcode_data, false);
                    }
                }
            }
        }

        $template = $this->options['template'];
        if (empty($template)) {
            return '';
        }

        $a = shortcode_atts(array('index' => -1), $atts);
        if ($a['index'] < 0) {
            $a['index'] = $this->_teaserIndex;

            $this->_teaserIndex++;
        }

        if (false === $this->_shortcode_data) {
            return '';
        }

        if ( ! isset($this->_shortcode_data['json'])) {
            return '';
        }

        if ( ! isset($this->_shortcode_data['json']->items[$a['index']])) {
            return '';
        }

        $item = $this->_shortcode_data['json']->items[$a['index']];

        return str_replace(
            array(
                '[link]',
                '[title]',
                '[lead]',
                '[image.url]',
                '[image.alt]',
                '[image.copyright]',
            ), array(
            $item->link,
            $item->title,
            $item->description,
            $item->image->url,
            $item->image->alt,
            $item->image->copyright,
        ), $template
        );
    }

}